#
# spec file for package yamagi-quake2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Luke Jones <luke.nukem.jones@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           yamagi-quake2
Version:        7.00
Release:        2.2
Summary:        Enhanced Quake 2 Source Port
License:        GPL-2.0
Group:          Amusements/Games/3D/Shoot
Url:            http://www.yamagi.org/quake2/
Source:         http://deponie.yamagi.org/quake2/quake2-%{version}.tar.xz
Source99:       %{name}.changes
Source100:      yamagi-quake2.appdata.xml
Patch0:         yamagi-quake2-fix-OpenGL-linking.diff
BuildRequires:  ImageMagick
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libSDL2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libvorbis-devel
BuildRequires:  openal-soft-devel
BuildRequires:  update-desktop-files
BuildRequires:  zlib-devel

%description
Yamagi Quake II is an enhanced client for id Software's Quake II. The
main focus is an unchanged single player experience; the gameplay and
graphics are unaltered. It also features: anisotropic filtering and
multi-sample anti-aliasing, widescreen aspect ratio and unlimited
screen size, compatibility with most mods, optional support for
retexturing packs and HUD scaling.

%prep
%setup -q -n quake2-%{version}
%patch0 -p1
# Fix usage of __DATE__ macro to prevent build in excess
modified="$(sed -n '/^ *$/n;/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
sed -i "s/__DATE__/${DATE}/g" src/common/misc.c src/game/savegame/savegame.c

%build
%cmake \
    -DSYSTEMWIDE_SUPPORT=ON
make %{_smp_mflags}

%install
q2dir="%{buildroot}%{_libexecdir}/%{name}"
install -dm 755 %{buildroot}%{_bindir}
install -Dpm 755 build/release/quake2 $q2dir/yquake2
install -Dpm 755 build/release/q2ded $q2dir/yq2ded
install -Dpm 644 build/release/ref_gl1.so $q2dir/ref_gl1.so
install -Dpm 644 build/release/ref_gl3.so $q2dir/ref_gl3.so
install -Dpm 644 build/release/baseq2/game.so $q2dir/baseq2/game.so
install -Dpm 644 stuff/yq2.cfg $q2dir/baseq2/yq2.cfg

# Install icons
install -Dpm 644 stuff/icon/Quake2.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/yquake2.svg
for res in 256 128 96 64 32 16; do
    mkdir -p "%{buildroot}%{_datadir}/icons/hicolor/$res"x"$res/apps"
    convert -strip stuff/icon/Quake2.png -resize $res"x"$res "%{buildroot}%{_datadir}/icons/hicolor/$res"x"$res/apps/yquake2.png"
done

# Install Wrapper
cat > %{buildroot}%{_bindir}/yquake2 << EOF
#!/bin/sh
exec "%{_libexecdir}/%{name}/\${0##*/}" \$@
EOF
ln -s yquake2 %{buildroot}%{_bindir}/yq2ded

install -D -p -m 644 %{SOURCE100}  %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
%suse_update_desktop_file -c yquake2 'Quake II' 'Yamagi Quake II' yquake2 yquake2 Game ActionGame

%post
%icon_theme_cache_post
cat << EOF

Please read README in %{_docdir}/%{name} for information on
how to install the needed gamedata files.

EOF

%postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc CHANGELOG CONTRIBUTE LICENSE README.md
%attr(0755,root,root) %{_bindir}/yquake2
%{_bindir}/yq2ded
%{_libexecdir}/%{name}
%{_datadir}/icons/hicolor/*/apps/yquake2.*
%{_datadir}/applications/yquake2.desktop
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Tue Jun 20 2017 bwiedemann@suse.com
- fix reproducible builds again
* Fri Jun  9 2017 mardnh@gmx.de
- Update to version 7.0.0
  + Remove the broken multitexturing render path from the OpenGL 1.4
    renderer. It was switched off by default in 6.00.
  + Reimplement the support for shared renderer libraries. Please note
    the this is an incompatible implementation with an custom API. The
    original renderer libraries will not work!
  + Implement an OpenGL 3.2 renderer. This renderer has the same look
    and feel as the old OpenGL 1.4 renderer but makes heavy use of
    modern OpenGL and GPU features. An OpenGL 3.2 capable GPU (Intel
    starting with Ivy Bridge on Windows or Sandy Bridge on Linux, Nvidia
    staring with G80 and AMD starting with R600 / HD2000) is required.
  + Fix OpenAL compatibility with modern openal-soft versions.
  + Several fixes and optimizations to OpenAL, implement support for
    doppler effects. (by xorw)
- Add patch:
  + yamagi-quake2-fix-OpenGL-linking.diff
* Tue May  2 2017 bwiedemann@suse.com
- use convert -strip to not have timestamps in png files
  to make build fully reproducible
* Fri Feb 10 2017 luke.nukem.jones@gmail.com
- Add appdata.xml
* Fri Dec 16 2016 luke.nukem.jones@gmail.com
  Update to version 6.00
- Make the client asynchronous. The old behaviour can be forced by
  setting cl_async to 0. Please note that asynchronicity can lead
  to problems if the old SDL 1.2 backend is used and vsync is
  enabled.
- Implement gl_overbrightbits in the non multitexturing case.  A
  value of 1 just fixes lighting on water surfaces, higher values
  increase the brightness of everything.
- General renderer overhaul for better compatibility with modern GPU
  OpenGL 1.4 is now required, older versions are no longer supported.
  Multitexturing was deprecated and will be removed in a future
  release.
- Fix some longstanding AI problems.
- Several general gameplay fixes.
- patch allow-custom-cflags.patch has been removed due to the
  package being forked in factory
* Mon Aug  1 2016 rpm@fthiessen.de
- Install into _libexecdir
- Install icons into icon-theme directory (hicolor)
* Mon Aug  1 2016 mardnh@gmx.de
- remove patch: yamagi-quake2-allow-overriding-cflags.patch since
  upstream now also have CMake support without this problem
- install binaries and libs to /usr/lib/yamagi-quake2/ and use a
  wrapper-script in /usr/bin/ to workaround rpath issues
- fix source url
* Tue Jul 19 2016 rpm@fthiessen.de
- Fixed file-contains-date-and-time rpmlint error
- Added allow-custom-cflags.patch to allow custom cflags for
  openSUSE's optflags.
- Compile with optflags
* Mon Jul 18 2016 jengelh@inai.de
- Update description to highlight the user-visible changes rather
  than implementation details.
* Fri Jul 15 2016 luke.nukem.jones@gmail.com
- Cleanup and prepare for Factory submission
* Sun Jul 10 2016 luke.nukem.jones@gmail.com
- Update to version 5.34:
  + Add support for stereo 3D (by Valery Guskov)
  + Make gibt solid so they move with conveyor belts.
  + Disable gl_ext_multitexturing by default.
  + Switch from an arch whitelist to an "all archs are supported"
    approach.
  + Add a new README.
* Thu May 19 2016 luke.nukem.jones@gmail.com
- Update to version 5.33
  + Add OGG volume slider in settings menu
  + Fixed some bugs in volume settings
- Remove unnessesary patch file
* Wed Jan  1 2014 gber@opensuse.org
- Initial packaging
